import Link from "next/link"
import { Button } from "@/components/ui/button"
import { Card, CardContent, CardDescription, CardHeader, CardTitle } from "@/components/ui/card"
import { Badge } from "@/components/ui/badge"
import { CheckCircle, Clock, Award, GraduationCap } from "lucide-react"

export default function HomePage() {
  return (
    <div className="min-h-screen bg-gradient-to-br from-slate-50 via-blue-50 to-indigo-50">
      {/* Navigation */}
      <nav className="bg-white/80 backdrop-blur-md border-b border-slate-200 sticky top-0 z-50">
        <div className="max-w-7xl mx-auto px-4 sm:px-6 lg:px-8">
          <div className="flex justify-between items-center h-16">
            <div className="flex items-center space-x-2">
              <GraduationCap className="h-8 w-8 text-blue-600" />
              <span className="text-xl font-bold text-slate-800">ProEssayWorks</span>
            </div>
            <div className="hidden md:flex items-center space-x-8">
              <Link href="/services" className="text-slate-600 hover:text-blue-600 font-medium transition-colors">
                Services
              </Link>
              <Link href="/how-it-works" className="text-slate-600 hover:text-blue-600 font-medium transition-colors">
                How It Works
              </Link>
              <Link href="/pricing" className="text-slate-600 hover:text-blue-600 font-medium transition-colors">
                Pricing
              </Link>
              <Link href="/about" className="text-slate-600 hover:text-blue-600 font-medium transition-colors">
                About
              </Link>
            </div>
            <div className="flex items-center space-x-4">
              <Link href="/auth/login">
                <Button variant="ghost" className="text-slate-600 hover:text-blue-600">
                  Sign In
                </Button>
              </Link>
              <Link href="/auth/register">
                <Button className="bg-blue-600 hover:bg-blue-700 text-white">Get Started</Button>
              </Link>
            </div>
          </div>
        </div>
      </nav>

      {/* Hero Section */}
      <section className="relative py-20 px-4 sm:px-6 lg:px-8">
        <div className="max-w-7xl mx-auto">
          <div className="text-center">
            <Badge className="mb-4 bg-blue-100 text-blue-800 border-blue-200">🎓 Academic Excellence Platform</Badge>
            <h1 className="text-4xl md:text-6xl font-bold text-slate-800 mb-6 leading-tight">
              Professional Academic
              <span className="text-blue-600 block">Writing Services</span>
            </h1>
            <p className="text-xl text-slate-600 mb-8 max-w-3xl mx-auto leading-relaxed">
              Connect with expert writers for high-quality essays, research papers, and academic assignments. Guaranteed
              plagiarism-free work with timely delivery.
            </p>
            <div className="flex flex-col sm:flex-row gap-4 justify-center">
              <Link href="/client/place-order">
                <Button size="lg" className="bg-blue-600 hover:bg-blue-700 text-white px-8 py-3 text-lg">
                  Place Your Order
                </Button>
              </Link>
              <Link href="/how-it-works">
                <Button size="lg" variant="outline" className="border-slate-300 text-slate-700 px-8 py-3 text-lg">
                  How It Works
                </Button>
              </Link>
            </div>
          </div>
        </div>
      </section>

      {/* Features Section */}
      <section className="py-16 px-4 sm:px-6 lg:px-8 bg-white">
        <div className="max-w-7xl mx-auto">
          <div className="text-center mb-12">
            <h2 className="text-3xl font-bold text-slate-800 mb-4">Why Choose ProEssayWorks?</h2>
            <p className="text-lg text-slate-600 max-w-2xl mx-auto">
              We provide exceptional academic writing services with a focus on quality, reliability, and student
              success.
            </p>
          </div>
          <div className="grid md:grid-cols-3 gap-8">
            <Card className="border-slate-200 hover:shadow-lg transition-shadow">
              <CardHeader>
                <CheckCircle className="h-12 w-12 text-green-600 mb-4" />
                <CardTitle className="text-slate-800">100% Original Work</CardTitle>
              </CardHeader>
              <CardContent>
                <CardDescription className="text-slate-600">
                  Every paper is written from scratch and checked for plagiarism using advanced detection tools.
                </CardDescription>
              </CardContent>
            </Card>
            <Card className="border-slate-200 hover:shadow-lg transition-shadow">
              <CardHeader>
                <Clock className="h-12 w-12 text-blue-600 mb-4" />
                <CardTitle className="text-slate-800">On-Time Delivery</CardTitle>
              </CardHeader>
              <CardContent>
                <CardDescription className="text-slate-600">
                  We guarantee timely delivery of your assignments, even with tight deadlines.
                </CardDescription>
              </CardContent>
            </Card>
            <Card className="border-slate-200 hover:shadow-lg transition-shadow">
              <CardHeader>
                <Award className="h-12 w-12 text-purple-600 mb-4" />
                <CardTitle className="text-slate-800">Expert Writers</CardTitle>
              </CardHeader>
              <CardContent>
                <CardDescription className="text-slate-600">
                  Our team consists of qualified academic writers with advanced degrees in various fields.
                </CardDescription>
              </CardContent>
            </Card>
          </div>
        </div>
      </section>

      {/* Pricing Preview */}
      <section className="py-16 px-4 sm:px-6 lg:px-8 bg-slate-50">
        <div className="max-w-7xl mx-auto">
          <div className="text-center mb-12">
            <h2 className="text-3xl font-bold text-slate-800 mb-4">Transparent Pricing</h2>
            <p className="text-lg text-slate-600">Starting from just $10 per page with no hidden fees</p>
          </div>
          <div className="grid md:grid-cols-4 gap-6">
            <Card className="border-slate-200">
              <CardHeader className="text-center">
                <CardTitle className="text-slate-800">High School</CardTitle>
                <div className="text-2xl font-bold text-blue-600">$10</div>
                <CardDescription>per page</CardDescription>
              </CardHeader>
            </Card>
            <Card className="border-slate-200">
              <CardHeader className="text-center">
                <CardTitle className="text-slate-800">Undergraduate</CardTitle>
                <div className="text-2xl font-bold text-blue-600">$13</div>
                <CardDescription>per page</CardDescription>
              </CardHeader>
            </Card>
            <Card className="border-slate-200">
              <CardHeader className="text-center">
                <CardTitle className="text-slate-800">Master's</CardTitle>
                <div className="text-2xl font-bold text-blue-600">$18</div>
                <CardDescription>per page</CardDescription>
              </CardHeader>
            </Card>
            <Card className="border-slate-200">
              <CardHeader className="text-center">
                <CardTitle className="text-slate-800">PhD</CardTitle>
                <div className="text-2xl font-bold text-blue-600">$25</div>
                <CardDescription>per page</CardDescription>
              </CardHeader>
            </Card>
          </div>
          <div className="text-center mt-8">
            <Link href="/pricing">
              <Button className="bg-blue-600 hover:bg-blue-700 text-white">View Full Pricing</Button>
            </Link>
          </div>
        </div>
      </section>

      {/* CTA Section */}
      <section className="py-16 px-4 sm:px-6 lg:px-8 bg-blue-600">
        <div className="max-w-4xl mx-auto text-center">
          <h2 className="text-3xl font-bold text-white mb-4">Ready to Get Started?</h2>
          <p className="text-xl text-blue-100 mb-8">
            Join thousands of students who trust ProEssayWorks for their academic success.
          </p>
          <div className="flex flex-col sm:flex-row gap-4 justify-center">
            <Link href="/auth/register">
              <Button size="lg" className="bg-white text-blue-600 hover:bg-slate-100 px-8 py-3 text-lg">
                Create Account
              </Button>
            </Link>
            <Link href="/client/place-order">
              <Button
                size="lg"
                variant="outline"
                className="border-white text-white hover:bg-white hover:text-blue-600 px-8 py-3 text-lg"
              >
                Place Order Now
              </Button>
            </Link>
          </div>
        </div>
      </section>

      {/* Footer */}
      <footer className="bg-slate-800 text-white py-12 px-4 sm:px-6 lg:px-8">
        <div className="max-w-7xl mx-auto">
          <div className="grid md:grid-cols-4 gap-8">
            <div>
              <div className="flex items-center space-x-2 mb-4">
                <GraduationCap className="h-6 w-6" />
                <span className="text-lg font-bold">ProEssayWorks</span>
              </div>
              <p className="text-slate-400">Professional academic writing services for students worldwide.</p>
            </div>
            <div>
              <h3 className="font-semibold mb-4">Services</h3>
              <ul className="space-y-2 text-slate-400">
                <li>
                  <Link href="/services" className="hover:text-white">
                    Essay Writing
                  </Link>
                </li>
                <li>
                  <Link href="/services" className="hover:text-white">
                    Research Papers
                  </Link>
                </li>
                <li>
                  <Link href="/services" className="hover:text-white">
                    Dissertations
                  </Link>
                </li>
                <li>
                  <Link href="/services" className="hover:text-white">
                    Editing
                  </Link>
                </li>
              </ul>
            </div>
            <div>
              <h3 className="font-semibold mb-4">Company</h3>
              <ul className="space-y-2 text-slate-400">
                <li>
                  <Link href="/about" className="hover:text-white">
                    About Us
                  </Link>
                </li>
                <li>
                  <Link href="/how-it-works" className="hover:text-white">
                    How It Works
                  </Link>
                </li>
                <li>
                  <Link href="/pricing" className="hover:text-white">
                    Pricing
                  </Link>
                </li>
              </ul>
            </div>
            <div>
              <h3 className="font-semibold mb-4">Support</h3>
              <ul className="space-y-2 text-slate-400">
                <li>
                  <a href="#" className="hover:text-white">
                    Contact Us
                  </a>
                </li>
                <li>
                  <a href="#" className="hover:text-white">
                    FAQ
                  </a>
                </li>
                <li>
                  <a href="#" className="hover:text-white">
                    Terms of Service
                  </a>
                </li>
                <li>
                  <a href="#" className="hover:text-white">
                    Privacy Policy
                  </a>
                </li>
              </ul>
            </div>
          </div>
          <div className="border-t border-slate-700 mt-8 pt-8 text-center text-slate-400">
            <p>&copy; 2024 ProEssayWorks. All rights reserved.</p>
          </div>
        </div>
      </footer>
    </div>
  )
}
